@@ -1,11 +1,11 @@
 from __future__ import absolute_import, unicode_literals
 
+import os
 import sys
 from subprocess import CalledProcessError
 
 import pytest
 
-from virtualenv.info import PY2
 from virtualenv.seed.wheels.acquire import download_wheel, pip_wheel_env_run
 from virtualenv.seed.wheels.embed import BUNDLE_FOLDER, get_embed_wheel
 from virtualenv.seed.wheels.util import discover_wheels
@@ -14,7 +14,7 @@ from virtualenv.seed.wheels.util import discover_wheels
 def test_pip_wheel_env_run_could_not_find(session_app_data, mocker):
     mocker.patch("virtualenv.seed.wheels.acquire.from_bundle", return_value=None)
     with pytest.raises(RuntimeError, match="could not find the embedded pip"):
-        pip_wheel_env_run([], session_app_data)
+        pip_wheel_env_run([], session_app_data, os.environ)
 
 
 def test_download_wheel_bad_output(mocker, for_py_version, session_app_data):
@@ -30,7 +30,9 @@ def test_download_wheel_bad_output(mocker, for_py_version, session_app_data):
     available = discover_wheels(BUNDLE_FOLDER, "setuptools", None, for_py_version)
     as_path.iterdir.return_value = [i.path for i in available]
 
-    result = download_wheel(distribution, "=={}".format(embed.version), for_py_version, [], session_app_data, as_path)
+    result = download_wheel(
+        distribution, "=={}".format(embed.version), for_py_version, [], session_app_data, as_path, os.environ
+    )
     assert result.path == embed.path
 
 
@@ -42,9 +44,9 @@ def test_download_fails(mocker, for_py_version, session_app_data):
 
     as_path = mocker.MagicMock()
     with pytest.raises(CalledProcessError) as context:
-        download_wheel("pip", "==1", for_py_version, [], session_app_data, as_path),
+        download_wheel("pip", "==1", for_py_version, [], session_app_data, as_path, os.environ),
     exc = context.value
-    if PY2:
+    if sys.version_info < (3, 5):
         assert exc.output == "outerr"
     else:
         assert exc.output == "out"
